Event

Enum Event 

#[non_exhaustive]
pub enum Event { Format { format: Format, }, }

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Format

pixel format description

Informs the client about a valid pixel format that can be used for buffers. Known formats include argb8888 and xrgb8888.

Extensions to drm_fourcc.h (or the format enum) do not require increasing the wl_shm version; as a result, clients may receive format codes which were not in the list at the time the client was made.

Fields

format: Format

buffer pixel format

Implementations

Source

impl Event

pub fn opcode(&self) -> u16

Get the opcode number of this message